import "./details.scss"
import {Renderer} from "@k8slens/extensions";
import React from "react";
import {ClusterVulnerabilityReport, Vulnerability, VulnerabilityReport} from "./types";
import {VulnerabilitiesList} from "./list";

const {
    Component: {
        KubeObjectMeta,
        DrawerItem,
        Badge,
    }
} = Renderer;

export interface ClusterVulnerabilityReportDetailsProps extends Renderer.Component.KubeObjectDetailsProps<ClusterVulnerabilityReport> {
    showObjectMeta?: boolean
}

export class ClusterVulnerabilityReportDetails extends React.Component<ClusterVulnerabilityReportDetailsProps> {

    render() {
        const {object: report} = this.props;
        const {report: {vulnerabilities: items}} = report;

        const vulnerabilities = items.map((vulnerability: Vulnerability) => new Vulnerability(vulnerability))
        if (!report) return null;
        return (
            <div className="VulnerabilityReportDetails">
                {this.props.showObjectMeta &&
                    <KubeObjectMeta object={report}
                                    hideFields={["uid", "resourceVersion", "selfLink"]}/>}

                <DrawerItem name="Container">
                    {report.metadata.labels['trivy-operator.container.name']}
                </DrawerItem>
                <DrawerItem name="Image">
                    {report.getImageRef()}
                </DrawerItem>

                <DrawerItem name="Summary" className="summary" labelsOnly>
                    <Badge className="Badge theme-critical"
                           label={report.report.summary.criticalCount}
                           tooltip="Critical"/>
                    <Badge className="Badge theme-high"
                           label={report.report.summary.highCount}
                           tooltip="High"/>
                    <Badge className="Badge theme-medium"
                           label={report.report.summary.mediumCount}
                           tooltip="Medium"/>
                    <Badge className="Badge theme-low"
                           label={report.report.summary.lowCount}
                           tooltip="Low"/>
                    <Badge className="Badge theme-unknown"
                           label={report.report.summary.unknownCount}
                           tooltip="Unknown"/>
                </DrawerItem>
                <VulnerabilitiesList vulnerabilities={vulnerabilities}/>
            </div>
        )
    }
}

export interface VulnerabilityReportDetailsProps extends Renderer.Component.KubeObjectDetailsProps<VulnerabilityReport> {

    /*
     * Determines whether to display ObjectMeta section or not.
     * We want to display it in the generic VulnerabilityReport view.
     * However, we want to hide it when we list VulnerabilityReports
     * in the WorkloadVulnerabilities details pane.
     */
    showObjectMeta?: boolean
}

export class VulnerabilityReportDetails extends React.Component<VulnerabilityReportDetailsProps> {

    render() {
        const {object: report} = this.props;
        const {report: {vulnerabilities: items}} = report;

        const vulnerabilities = items.map((vulnerability) => new Vulnerability(vulnerability))
        if (!report) {
            return null;
        }
        return (
            <div className="VulnerabilityReportDetails">
                {this.props.showObjectMeta &&
                    <KubeObjectMeta object={report}
                                    hideFields={["uid", "resourceVersion", "selfLink"]}/>}

                <DrawerItem name="Container">
                    {report.metadata.labels['trivy-operator.container.name']}
                </DrawerItem>
                <DrawerItem name="Image">
                    {report.getImageRef()}
                </DrawerItem>

                <DrawerItem name="Summary" className="summary" labelsOnly>
                    <Badge className="Badge theme-critical"
                           label={report.report.summary.criticalCount}
                           tooltip="Critical"/>
                    <Badge className="Badge theme-high"
                           label={report.report.summary.highCount}
                           tooltip="High"/>
                    <Badge className="Badge theme-medium"
                           label={report.report.summary.mediumCount}
                           tooltip="Medium"/>
                    <Badge className="Badge theme-low"
                           label={report.report.summary.lowCount}
                           tooltip="Low"/>
                    <Badge className="Badge theme-unknown"
                           label={report.report.summary.unknownCount}
                           tooltip="Unknown"/>
                </DrawerItem>
                <VulnerabilitiesList vulnerabilities={vulnerabilities}/>
            </div>
        )
    }
}
